import request from '@/utils/request'

// 查询角色列表
export function listRole(query) {
  return request({
    url: '/system/role/list',
    method: 'get',
    params: query
  })
}

// 查询角色详细
export function getRole(roleId) {
  return request({
    url: '/system/role/' + roleId,
    method: 'get'
  })
}

// 新增角色
export function addRole(data) {
  return request({
    url: '/system/role',
    method: 'post',
    data: data
  })
}

// 修改角色
export function updateRole(data) {
  return request({
    url: '/system/role',
    method: 'put',
    data: data
  })
}

// 角色数据权限
export function dataScope(data) {
  return request({
    url: '/system/role/dataScope',
    method: 'put',
    data: data
  })
}

// 角色状态修改
export function changeRoleStatus(roleId, status) {
  const data = {
    roleId,
    status
  }
  return request({
    url: '/system/role/changeStatus',
    method: 'put',
    data: data
  })
}

// 删除角色
export function delRole(roleId) {
  return request({
    url: '/system/role/' + roleId,
    method: 'delete'
  })
}

// 查询角色已授权用户列表
export function allocatedUserList(query) {
  return request({
    url: '/system/role/authUser/allocatedList',
    method: 'get',
    params: query
  })
}

// 查询角色未授权用户列表
export function unallocatedUserList(query) {
  return request({
    url: '/system/role/authUser/unallocatedList',
    method: 'get',
    params: query
  })
}

// 取消用户授权角色
export function authUserCancel(data) {
  return request({
    url: '/system/role/authUser/cancel',
    method: 'put',
    data: data
  })
}

// 批量取消用户授权角色
// export function authUserCancelAll(data) {
//   return request({
//     url: '/system/role/authUser/cancelAll',
//     method: 'put',
//     params: data
//   })
// }

// 授权用户选择
export function authUserSelectAll(data) {
  return request({
    url: '/system/role/authUser/selectAll',
    method: 'put',
    params: data
  })
}

// 加载对应角色菜单列表树
export function getRoleMenuTreeselect(roleId) {
  return request({
    url: 'system/menu/roleMenuSelect/' + roleId,
    method: 'get'
  })
}

// 批量保存角色菜单权限
export function saveRoleMenu(data) {
  return request({
    url: '/system/role/saveRoleMenu',
    method: 'put',
    data: data
  })
}

// 批量取消授权用户
export function authUserCancelAll(data) {
  return request({
    url: '/system/role/cancelRoleMenu',
    method: 'put',
    data: data
  })
}

// 查询角色菜单表头权限列表
export function getTableHeadList(roleId, menuId, checkStatus) {
  return request({
    url: '/system/role/tableHeadList/?roleId=' + roleId + '&menuId=' + menuId + '&checkStatus=' + checkStatus,
    method: 'get'
  })
}

// 表头状态修改
export function setSysTableCfgIsShow(cfgId, isShow, menuId, roleId) {
  const data = {
    cfgId,
    isShow,
    menuId,
    roleId,
  }
  return request({
    url: '/system/role/setSysTableCfgIsShow',
    method: 'put',
    data: data
  })
}